@@ -22,14 +22,15 @@ sub new {
 sub switch {
 	my ($self, $s) = @_;
 
-	### return references to keywords in symbol table
+	### return references to ID classes in symbol table
 	given ($s) {
 	when (Cobol::Compiler::COBOLMainLexer->IDENTIFICATION) { 
 		return \$self->{mastersymtab}->{IDENTIFICATION}	
 	}
 	when (Cobol::Compiler::COBOLMainLexer->PROGRAM-ID) {  }
-		return \$self->{mastersymtab}->{IDENTIFICATION}	
+		return \$self->{mastersymtab}->{PROGRAM-ID}	
 	}
+
 	return nil;
 }
 
